[asl] 102/177: Fixing typos

Ghislain Vaillant ghisvail-guest at moszumanska.debian.org
Thu Aug 27 09:22:45 UTC 2015


This is an automated email from the git hooks/post-receive script.

ghisvail-guest pushed a commit to branch master
in repository asl.

commit 4250362c79197e65b4d416e5aabc77885d7a50c9
Author: Avtech Scientific <AvtechScientific at users.noreply.github.com>
Date:   Wed Jul 15 22:05:52 2015 +0300

    Fixing typos
---
 src/num/aslCrystalGrowthBC.h | 13 +++++++------
 src/num/aslLSFacetedGrowth.h |  2 +-
 2 files changed, 8 insertions(+), 7 deletions(-)

diff --git a/src/num/aslLSFacetedGrowth.h b/src/num/aslLSFacetedGrowth.h
index e0f3d59..c3db585 100644
--- a/src/num/aslLSFacetedGrowth.h
+++ b/src/num/aslLSFacetedGrowth.h
@@ -51,7 +51,7 @@ namespace asl
 			acl::VectorOfElements betaDislACL;	
 		public:
 
-			/// generates code which resullts the number corresponds to nearest direction
+			/// generates code which results the number corresponds to nearest direction
 			void directionCode(acl::VectorOfElements normal,
 				               acl::VectorOfElements direction,
 			                   acl::VectorOfElements cosTheta,

diff --git a/src/num/aslCrystalGrowthBC.h b/src/num/aslCrystalGrowthBC.h
index de1bbd8..f2bf6df 100644
--- a/src/num/aslCrystalGrowthBC.h
+++ b/src/num/aslCrystalGrowthBC.h
@@ -29,20 +29,20 @@
 #include <acl/aclMath/aclVectorOfElementsDef.h>
 
 
-namespace acl{
+namespace acl
+{
 	class Kernel;
 	typedef std::shared_ptr<Kernel> SPKernel;
 }
 
-
-
 namespace asl
 {
 	class PositionFunction;
 	typedef std::shared_ptr<PositionFunction> SPPositionFunction;
 
 	
-	/// Bondary condition that makes gradient	proportional to a surface concentration \ingroup BoundaryConditions		 
+	/** Boundary condition that makes gradient proportional to a surface concentration
+		\ingroup BoundaryConditions */		 
 	class BCLinearGrowthMap:public BCondWithMap
 	{		
 		public:
@@ -69,7 +69,7 @@ namespace asl
 			virtual void init();			
 	};
 
 	/// Bondary condition that makes gradient proportional to a surface concentration 
 	/**	
 		 \ingroup BoundaryConditions
 		 The boundary condition corresponds to different system with surface reaction. 
@@ -143,7 +143,8 @@ namespace asl
 			virtual void init();			
 	};
 
-	/// Bondary condition that makes gradient proportional to a surface concentration, second order \ingroup BoundaryConditions		 
+	/** Boundary condition that makes gradient proportional to a surface concentration, second order
+	 \ingroup BoundaryConditions */		 
 	class BCLinearGrowthMap2:public BCondWithMap
 	{		
 		public:
@@ -69,7 +69,7 @@ namespace asl
 	};
 
-	/// Bondary condition that makes gradient proportional to a surface concentration 
+	/// Boundary condition that makes gradient proportional to a surface concentration 
 	/**	
 		 \ingroup BoundaryConditions
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/debian-science/packages/asl.git



More information about the debian-science-commits mailing list